==> zio-aws-cloudfront_2.13-5.17.104.3-sources.jar: zio/aws/cloudfront/model/DistributionList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class DistributionList(
    marker: String,
    nextMarker: Option[String] = None,
    maxItems: Integer,
    isTruncated: Boolean,
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.DistributionSummary]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.DistributionList = {
    import DistributionList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.DistributionList
      .builder()
      .marker(marker: java.lang.String)
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(Integer.unwrap(maxItems): java.lang.Integer)
      .isTruncated(isTruncated: java.lang.Boolean)
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.DistributionList.ReadOnly =
    zio.aws.cloudfront.model.DistributionList.wrap(buildAwsValue())
}
object DistributionList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.DistributionList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.DistributionList =
      zio.aws.cloudfront.model.DistributionList(
        marker,
        nextMarker.map(value => value),
        maxItems,
        isTruncated,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: String
    def nextMarker: Option[String]
    def maxItems: Integer
    def isTruncated: Boolean
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.DistributionSummary.ReadOnly]]
    def getMarker: ZIO[Any, Nothing, String] = ZIO.succeed(marker)
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getIsTruncated: ZIO[Any, Nothing, Boolean] = ZIO.succeed(isTruncated)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.DistributionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.DistributionList
  ) extends zio.aws.cloudfront.model.DistributionList.ReadOnly {
    override val marker: String = impl.marker(): String
    override val nextMarker: Option[String] =
      scala.Option(impl.nextMarker()).map(value => value: String)
    override val maxItems: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.maxItems())
    override val isTruncated: Boolean = impl.isTruncated(): Boolean
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items
        : Option[List[zio.aws.cloudfront.model.DistributionSummary.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.DistributionSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.DistributionList
  ): zio.aws.cloudfront.model.DistributionList.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.158.4-sources.jar: zio/aws/cloudfront/model/DistributionList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class DistributionList(
    marker: String,
    nextMarker: Option[String] = None,
    maxItems: Integer,
    isTruncated: Boolean,
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.DistributionSummary]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.DistributionList = {
    import DistributionList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.DistributionList
      .builder()
      .marker(marker: java.lang.String)
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(maxItems: java.lang.Integer)
      .isTruncated(isTruncated: java.lang.Boolean)
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.DistributionList.ReadOnly =
    zio.aws.cloudfront.model.DistributionList.wrap(buildAwsValue())
}
object DistributionList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.DistributionList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.DistributionList =
      zio.aws.cloudfront.model.DistributionList(
        marker,
        nextMarker.map(value => value),
        maxItems,
        isTruncated,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: String
    def nextMarker: Option[String]
    def maxItems: Integer
    def isTruncated: Boolean
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.DistributionSummary.ReadOnly]]
    def getMarker: ZIO[Any, Nothing, String] = ZIO.succeed(marker)
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getIsTruncated: ZIO[Any, Nothing, Boolean] = ZIO.succeed(isTruncated)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.DistributionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.DistributionList
  ) extends zio.aws.cloudfront.model.DistributionList.ReadOnly {
    override val marker: String = impl.marker(): String
    override val nextMarker: Option[String] =
      scala.Option(impl.nextMarker()).map(value => value: String)
    override val maxItems: Integer = impl.maxItems(): Integer
    override val isTruncated: Boolean = impl.isTruncated(): Boolean
    override val quantity: Integer = impl.quantity(): Integer
    override val items
        : Option[List[zio.aws.cloudfront.model.DistributionSummary.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.DistributionSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.DistributionList
  ): zio.aws.cloudfront.model.DistributionList.ReadOnly = new Wrapper(impl)
}
